@@ -94,6 +94,12 @@ class SMBSlave : public QObject, public KIO::SlaveBase
     Q_OBJECT
 
 private:
+    class SMBError {
+    public:
+        int kioErrorId;
+        QString errorString;
+    };
+
     //---------------------------------------------------------------------
     // please make sure your private data does not duplicate existing data
     //---------------------------------------------------------------------
@@ -156,10 +162,9 @@ protected:
      * Description :  Return a stat of given SMBUrl. Calls cache_stat and
      *                pack it in UDSEntry. UDSEntry will not be cleared
      * Parameter :    SMBUrl the url to stat
-     *                ignore_errors do not call error(), but warning()
-     * Return :       false if any error occurred (errno), else true
+     * Return :       cache_stat() return code
      */
-    bool browse_stat_path(const SMBUrl& url, UDSEntry& udsentry, bool ignore_errors);
+    int browse_stat_path(const SMBUrl& url, UDSEntry& udsentry);
 
     /**
      * Description :  call smbc_stat and return stats of the url
@@ -212,7 +217,8 @@ protected:
      */
     QUrl checkURL(const QUrl& kurl) const;
 
-    void reportError(const SMBUrl &kurl, const int &errNum);
+    void reportError(const SMBUrl& url, const int errNum);
+    void reportWarning(const SMBUrl& url, const int errNum);
 
 public:
 
@@ -268,6 +274,7 @@ protected:
     void virtual_hook(int id, void *data) Q_DECL_OVERRIDE;
 
 private:
+    SMBError errnumToKioError(const SMBUrl& url, const int errNum);
     void smbCopy(const QUrl& src, const QUrl &dest, int permissions, KIO::JobFlags flags);
     void smbCopyGet(const QUrl& src, const QUrl& dest, int permissions, KIO::JobFlags flags);
     void smbCopyPut(const QUrl& src, const QUrl& dest, int permissions, KIO::JobFlags flags);
