@@ -21,7 +21,6 @@
 #include "thumbnail.h"
 
 #include <stdlib.h>
-#include <unistd.h>
 #ifdef __FreeBSD__
     #include <machine/param.h>
 #endif
@@ -29,6 +28,7 @@
 #ifndef Q_OS_WIN
 #include <sys/ipc.h>
 #include <sys/shm.h>
+#include <unistd.h> // nice()
 #endif
 
 #include <QApplication>
@@ -48,6 +48,7 @@
 #include <QTemporaryFile>
 #include <QDebug>
 
+#include <KFileItem>
 #include <KLocalizedString>
 #include <KSharedConfig>
 #include <KConfigGroup>
@@ -57,7 +58,6 @@
 
 #include <kaboutdata.h>
 #include <kiconloader.h>
-#include <kde_file.h>
 
 #include <kio/thumbcreator.h>
 #include <kio/thumbsequencecreator.h>
@@ -452,7 +452,7 @@ QImage ThumbnailProtocol::thumbForDirectory(const QUrl& directory)
         // Directories that the directory preview will be propagated into if there is no direct sub-directories
         const KConfigGroup globalConfig(KSharedConfig::openConfig(), "PreviewSettings");
         m_propagationDirectories = globalConfig.readEntry("PropagationDirectories", QStringList() << "VIDEO_TS").toSet();
-        m_maxFileSize = globalConfig.readEntry("MaximumSize", 5 * 1024 * 1024); // 5 MByte default
+        m_maxFileSize = globalConfig.readEntry("MaximumSize", qulonglong(5 * 1024 * 1024)); // 5 MByte default
     }
 
     const int tiles = 2; //Count of items shown on each dimension
@@ -463,11 +463,10 @@ QImage ThumbnailProtocol::thumbForDirectory(const QUrl& directory)
     // Provide a fallback solution for other iconsets (e. g. draw folder
     // only as small overlay, use no margins)
 
-    //Use the current (custom) folder icon
-    const QMimeDatabase db;
-    const QString iconName = db.mimeTypeForName("inode/directory").iconName();
+    QString localFile = directory.path();
 
-    const QPixmap folder = QIcon::fromTheme(iconName).pixmap(qMin(m_width, m_height));
+    KFileItem item(QUrl::fromLocalFile(localFile));
+    const QPixmap folder = QIcon::fromTheme(item.iconName()).pixmap(qMin(m_width, m_height));
 
     const int folderWidth  = folder.width();
     const int folderHeight = folder.height();
@@ -484,8 +483,6 @@ QImage ThumbnailProtocol::thumbForDirectory(const QUrl& directory)
         return img;
     }
 
-    QString localFile = directory.path();
-
     // Multiply with a high number, so we get some semi-random sequence
     int skipValidItems = ((int)sequenceIndex()) * tiles * tiles;
 
